==> estateplat-common-1.1.0-20170401.084346-281-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCjlb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.lang.String;
import java.util.Date;

/**
 *
 *持件列表
 * @author <a href="mailto:houqizheng@gtmap.cn">houqz</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_cjlb")
public class BdcCjlb implements Serializable {
    @Id
    private String cjid; //持件Id

    private String bh;//项目编号

    private String zl;//坐落

    private Date cysj;//持有时间

    private String cyr;//持有人

    private String bz;//备注

    private String sqr;//申请人

    private String pc;//批次

    public String getCjid() {
        return cjid;
    }

    public void setCjid(String cjid) {
        this.cjid = cjid;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Date getCysj() {
        return cysj;
    }

    public void setCysj(Date cysj) {
        this.cysj = cysj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getCyr() {
        return cyr;
    }

    public void setCyr(String cyr) {
        this.cyr = cyr;
    }

    public String getPc() {
        return pc;
    }

    public void setPc(String pc) {
        this.pc = pc;
    }
}

==> estateplat-common-1.2.4-20220519.005419-1024-sources.jar: cn/gtmap/estateplat/model/server/core/BdcCjlb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.lang.String;
import java.util.Date;

/**
 *
 *持件列表
 * @author <a href="mailto:houqizheng@gtmap.cn">houqz</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_cjlb")
public class BdcCjlb implements Serializable {
    @Id
    private String cjid; //持件Id

    private String bh;//项目编号

    private String zl;//坐落

    private Date cysj;//持有时间

    private String cyr;//持有人

    private String bz;//备注

    private String sqr;//申请人

    private String pc;//批次
    private String zsbh;//证书编号

    public String getCjid() {
        return cjid;
    }

    public void setCjid(String cjid) {
        this.cjid = cjid;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Date getCysj() {
        return cysj;
    }

    public void setCysj(Date cysj) {
        this.cysj = cysj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getCyr() {
        return cyr;
    }

    public void setCyr(String cyr) {
        this.cyr = cyr;
    }

    public String getPc() {
        return pc;
    }

    public void setPc(String pc) {
        this.pc = pc;
    }

    public String getZsbh() {
        return zsbh;
    }

    public void setZsbh(String zsbh) {
        this.zsbh = zsbh;
    }
}
